@@ -12,7 +12,7 @@ class TestFinance(unittest.TestCase):
     def setUpClass(cls):
         _dir = os.path.join(os.path.dirname(__file__), "../../data")
         client = DocumentClient()
-        file_path = client.get_xbrl("S100G2KL", save_dir=_dir,
+        file_path = client.get_xbrl("S100G6IU", save_dir=_dir,
                                     expand_level="dir")
         cls.reader = Reader(file_path)
 
@@ -61,6 +61,6 @@ class TestFinance(unittest.TestCase):
 
     def test_pl_ifrs(self):
         pl = self.reader.extract(Finance).pl(ifrs=True)
-        # pl.to_csv("pl_ifrs.csv", index=False, encoding="shift_jis")
+       #  pl.to_csv("pl_ifrs.csv", index=False, encoding="shift_jis")
         self.assertTrue(pl is not None)
         self.assertGreater(len(pl), 0)
